@@ -46,20 +46,17 @@ class DatabaseAPI(object):
     _ACCOUNTS_RESOURCE = 'accounts'
     _LOGS_RESOURCE = 'logs'
 
-    def __init__(self, token: str):
+    def __init__(self, token=None):
         """
-        Provide a valid authentication token in order to use the endpoints accessible by the account that is associated
-        with the token. If an invalid authentication token is provided, the initializer will raise an exception.
-
+        Provide a optional authentication token in order to use the endpoints accessible by the account that is
+        associated with the token.
         :param token: An authentication token.
-        :raises InvalidToken: When an invalid authentication token is provided.
+        :raises TypeError: When input token isn't a string or None.
         """
-        if not isinstance(token, str):
+        if token is not None and not isinstance(token, str):
             raise TypeError
-        if not token:
-            raise ValueError
         self.token = token
-        self.auth = requests.auth.HTTPBasicAuth(username=self.token, password='')
+        self.auth = requests.auth.HTTPBasicAuth(username=self.token, password='') if token else None
 
     ###################################
     # Class properties
@@ -276,9 +273,9 @@ class DatabaseAPI(object):
         updates = {'stability': stability}
         return self._patch(DatabaseAPI._artifact_image_tag_endpoint(image_tag), updates)
 
-    def set_artifact_current_status(self, image_tag: str, status: str, date: str) -> Response:
+    def set_artifact_reproducibility_status(self, image_tag: str, status: str, date: str) -> Response:
         """
-        Update the current status of an artifact.
+        Update the reproducibility status of an artifact.
 
         :param image_tag: The image tag identifying the artifact to update.
         :param status: Unreproducible/Reproducible/Broken/Flaky.
@@ -295,7 +292,7 @@ class DatabaseAPI(object):
             datetime.datetime.strptime(date, '%Y-%m-%d')
         except ValueError:
             raise ValueError("Incorrect data format, should be YYYY-MM-DD")
-        updates = {'current_status': {'status': status, 'time_stamp': date}}
+        updates = {'reproducibility_status': {'status': status, 'time_stamp': date}}
         return self._patch(DatabaseAPI._artifact_image_tag_endpoint(image_tag), updates)
 
     def update_artifact_repo_name(self, image_tag: str, new_repo: str) -> Response:
@@ -601,8 +598,12 @@ class DatabaseAPI(object):
         resp = requests.get(endpoint, auth=self.auth)
         # Do not print an error message if the entity was not expected to be found and we got a 404 status code.
         not_found = resp.status_code == 404
+        rate_limited = resp.status_code == 429
         if not_found and not error_if_not_found:
             return resp
+        elif rate_limited:
+            log.error('You are being rate limited. You can request a API token to remove this limit.')
+            log.error('http://www.bugswarm.org/contact/')
         elif not resp.ok:
             log.error(resp.url)
             log.error(resp.content)
